@@ -30,6 +30,8 @@ if [ $# = 0 ] ;then
     fi
 fi
 
+STARTUP_WAIT=true
+
 for OPTION in "$@"
 do
 	case $OPTION in
@@ -42,10 +44,14 @@ do
 		-c)
 			. ${HINEMOS_HOME}/sbin/mng/hinemos_clear_jbm.sh
 			;;
+		-W)
+			STARTUP_WAIT=false
+			;;
 		*)
 			echo "usage"
 			echo "jboss_start.sh    : JBoss is started as usual. "
 			echo "jboss_start.sh -c : After the JMS message is annulled, JBoss is started. "
+			echo "jboss_start.sh -W : startup JBoss (not wait for the start to complete)"
 			exit 1
 			;;
 	esac
@@ -98,6 +104,11 @@ cd ${HINEMOS_HOME}/var/log
 
 while [ 1 ];
 do
+	if [ "x${STARTUP_WAIT}" == "xfalse" ]
+	then
+		break
+	fi
+
         if [ -f ${HINEMOS_HOME}/var/log/jboss.log ]; then
                 LOG_DATE=`tail -1 /opt/hinemos/var/log/jboss.log | gawk -F\  '{ print $1 }'`
                 if [ "${TODAY}" = "${LOG_DATE}" ];  then
