@@ -40,7 +40,7 @@ syslogng_uninstall() {
 				/etc/init.d/syslog start
     			/sbin/chkconfig --level 2345 syslog-ng off
 				/sbin/chkconfig --level 2345 syslog on
-				rpm -e syslog-ng libol
+				rpm -e syslog-ng libevtlog0
 				echo "syslog-ngをアンインストールしました。"
 				echo ""
 				echo "syslog-ng.confのバックアップファイルが作成されました。"
